@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                #
+# Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -992,6 +992,7 @@ TM_VCENTER_FILES="src/tm_mad/vcenter/clone \
                  src/tm_mad/vcenter/snap_delete \
                  src/tm_mad/vcenter/snap_revert \
                  src/tm_mad/vcenter/failmigrate \
+                 src/datastore_mad/remotes/vcenter/monitor \
                  src/tm_mad/vcenter/delete"
 
 TM_ISCSI_FILES="src/tm_mad/iscsi_libvirt/clone \
@@ -1225,7 +1226,8 @@ WEBSOCKIFY_SHARE_FILES="share/websockify/websocketproxy.py \
 #-------------------------------------------------------------------------------
 
 HOOK_FT_FILES="share/hooks/host_error.rb \
-               share/hooks/fence_host.sh"
+               share/hooks/fence_host.sh \
+               share/hooks/delete_poweroff_vms.rb"
 
 #-------------------------------------------------------------------------------
 # Installation scripts, to be installed under $SHARE_LOCATION
