@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 
 # ---------------------------------------------------------------------------- #
-# Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                  #
+# Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                  #
 #                                                                              #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may      #
 # not use this file except in compliance with the License. You may obtain      #
@@ -40,6 +40,12 @@ begin
 
     ds = vi_client.get_datastore(ds_name)
 
+    if ds.is_a? RbVmomi::VIM::StoragePod
+        STDERR.puts "Cannot upload image to StoragePod #{ds_name} on #{hostname}."\
+                    "Reason: Not supported"
+        exit(-1)
+    end
+
     # Monkey path datastore objects. Can not be done patching the class
     # as the library redefines it when a new object is created. Using both
     # the database vmodl.db and the Datastore.rb
