@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                #
+# Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -2637,7 +2637,7 @@ EOT
     # Params:
     # +disk+:: Nokogiri::XML::Node describing a disk used by a template
     def get_image_from_name(disk)
-      name = disk.at_xpath("IMAGE").content # always defined
+      name = disk.at_xpath("IMAGE") && disk.at_xpath("IMAGE").content
       uid = disk.at_xpath("IMAGE_UID")
       uname = disk.at_xpath("IMAGE_UNAME")
 
