@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                #
+# Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -14,17 +14,19 @@
 # limitations under the License.                                             #
 #--------------------------------------------------------------------------- #
 
+require "rexml/document"
+include REXML
+
 module Migrator
     def db_version
-        "4.4.0"
+        "2.9.90"
     end
 
     def one_version
-        "OpenNebula 4.4.0"
+        "OpenNebula 2.9.90"
     end
 
     def up
-        @db.run "UPDATE host_pool SET last_mon_time=0 WHERE last_mon_time IS NULL;"
         return true
     end
 end
