@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -123,12 +123,7 @@ define(function(require) {
 
     $("#provision_add_ssh_key_form").submit(function() {
       var keypair = $('#provision_ssh_key', this).val();
-
-      if (!keypair.length) {
-        Notifier.notifyError(Locale.tr("You have to provide an SSH key"));
-        return false;
-      }
-
+      
       var template_str = 'SSH_PUBLIC_KEY = "'+TemplateUtils.escapeDoubleQuotes(keypair)+'"';
 
       Sunstone.runAction("User.append_template", "-1", template_str);
