@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------- #
-# Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                #
+# Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                #
 #                                                                            #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may    #
 # not use this file except in compliance with the License. You may obtain    #
@@ -54,4 +54,17 @@ class VXLANDriver < VNMMAD::VLANDriver
 
         OpenNebula.exec_and_log("#{command(:ip)} link set #{@nic[:vlan_dev]} up")
     end
+
+    def get_interface_vlan(name)
+        text = %x(#{command(:ip)} -d link show #{name})
+        return nil if $?.exitstatus != 0
+
+        text.each_line do |line|
+            m = line.match(/^\s*vxlan id (\d+)/)
+
+            return m[1] if m
+        end
+
+        nil
+    end
 end
